# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities

__all__ = ['VpcPublicGatewayDhcpArgs', 'VpcPublicGatewayDhcp']

@pulumi.input_type
class VpcPublicGatewayDhcpArgs:
    def __init__(__self__, *,
                 subnet: pulumi.Input[_builtins.str],
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_local_name: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_searches: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dns_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 enable_dynamic: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_high: Optional[pulumi.Input[_builtins.str]] = None,
                 pool_low: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 push_default_route: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_dns_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 rebind_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 renew_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 valid_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a VpcPublicGatewayDhcp resource.
        :param pulumi.Input[_builtins.str] subnet: The subnet to associate with the Public Gateway DHCP configuration.
        :param pulumi.Input[_builtins.str] address: The IP address of the DHCP server. This will be the gateway's address in the Private Network.
        :param pulumi.Input[_builtins.str] dns_local_name: TLD given to hostnames in the Private Network. Allowed characters are `a-z0-9-.`. Defaults to the slugified Private Network name if created along a GatewayNetwork, or else to `priv`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_searches: Additional DNS search paths
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_servers_overrides: Override the DNS server list pushed to DHCP clients, instead of the gateway itself.
        :param pulumi.Input[_builtins.bool] enable_dynamic: Whether to enable dynamic pooling of IPs. By turning the dynamic pool off, only pre-existing DHCP reservations will be handed out. Defaults to `true`.
        :param pulumi.Input[_builtins.str] pool_high: High IP (excluded) of the dynamic address pool. Defaults to the last address of the subnet.
        :param pulumi.Input[_builtins.str] pool_low: Low IP (included) of the dynamic address pool. Defaults to the second address of the subnet.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Public Gateway DHCP configuration is associated with.
        :param pulumi.Input[_builtins.bool] push_default_route: Whether the gateway should push a default route to DHCP clients or only hand out IPs. Defaults to `true`.
               
               > **Warning**: If you need to setup a default route, it's recommended to use the `network.GatewayNetwork` resource instead.
        :param pulumi.Input[_builtins.bool] push_dns_server: Whether the gateway should push custom DNS servers to clients. This allows for instance hostname > IP resolution. Defaults to `true`.
        :param pulumi.Input[_builtins.int] rebind_timer: After how long, in seconds, a DHCP client will query for a new lease if previous renews fail. Must be 30s lower than `valid_lifetime`. Defaults to 51m (3060s).
        :param pulumi.Input[_builtins.int] renew_timer: After how long, in seconds, a renewal will be attempted. Must be 30s lower than `rebind_timer`. Defaults to 50m (3000s).
        :param pulumi.Input[_builtins.int] valid_lifetime: How long, in seconds, DHCP entries will be valid. Defaults to 1h (3600s).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Public Gateway DHCP configuration should be created.
        """
        pulumi.set(__self__, "subnet", subnet)
        if address is not None:
            pulumi.set(__self__, "address", address)
        if dns_local_name is not None:
            pulumi.set(__self__, "dns_local_name", dns_local_name)
        if dns_searches is not None:
            pulumi.set(__self__, "dns_searches", dns_searches)
        if dns_servers_overrides is not None:
            pulumi.set(__self__, "dns_servers_overrides", dns_servers_overrides)
        if enable_dynamic is not None:
            pulumi.set(__self__, "enable_dynamic", enable_dynamic)
        if pool_high is not None:
            pulumi.set(__self__, "pool_high", pool_high)
        if pool_low is not None:
            pulumi.set(__self__, "pool_low", pool_low)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if push_default_route is not None:
            pulumi.set(__self__, "push_default_route", push_default_route)
        if push_dns_server is not None:
            pulumi.set(__self__, "push_dns_server", push_dns_server)
        if rebind_timer is not None:
            pulumi.set(__self__, "rebind_timer", rebind_timer)
        if renew_timer is not None:
            pulumi.set(__self__, "renew_timer", renew_timer)
        if valid_lifetime is not None:
            pulumi.set(__self__, "valid_lifetime", valid_lifetime)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def subnet(self) -> pulumi.Input[_builtins.str]:
        """
        The subnet to associate with the Public Gateway DHCP configuration.
        """
        return pulumi.get(self, "subnet")

    @subnet.setter
    def subnet(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "subnet", value)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP address of the DHCP server. This will be the gateway's address in the Private Network.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter(name="dnsLocalName")
    def dns_local_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        TLD given to hostnames in the Private Network. Allowed characters are `a-z0-9-.`. Defaults to the slugified Private Network name if created along a GatewayNetwork, or else to `priv`.
        """
        return pulumi.get(self, "dns_local_name")

    @dns_local_name.setter
    def dns_local_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dns_local_name", value)

    @_builtins.property
    @pulumi.getter(name="dnsSearches")
    def dns_searches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Additional DNS search paths
        """
        return pulumi.get(self, "dns_searches")

    @dns_searches.setter
    def dns_searches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dns_searches", value)

    @_builtins.property
    @pulumi.getter(name="dnsServersOverrides")
    def dns_servers_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Override the DNS server list pushed to DHCP clients, instead of the gateway itself.
        """
        return pulumi.get(self, "dns_servers_overrides")

    @dns_servers_overrides.setter
    def dns_servers_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dns_servers_overrides", value)

    @_builtins.property
    @pulumi.getter(name="enableDynamic")
    def enable_dynamic(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable dynamic pooling of IPs. By turning the dynamic pool off, only pre-existing DHCP reservations will be handed out. Defaults to `true`.
        """
        return pulumi.get(self, "enable_dynamic")

    @enable_dynamic.setter
    def enable_dynamic(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_dynamic", value)

    @_builtins.property
    @pulumi.getter(name="poolHigh")
    def pool_high(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        High IP (excluded) of the dynamic address pool. Defaults to the last address of the subnet.
        """
        return pulumi.get(self, "pool_high")

    @pool_high.setter
    def pool_high(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pool_high", value)

    @_builtins.property
    @pulumi.getter(name="poolLow")
    def pool_low(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Low IP (included) of the dynamic address pool. Defaults to the second address of the subnet.
        """
        return pulumi.get(self, "pool_low")

    @pool_low.setter
    def pool_low(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pool_low", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project the Public Gateway DHCP configuration is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="pushDefaultRoute")
    def push_default_route(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the gateway should push a default route to DHCP clients or only hand out IPs. Defaults to `true`.

        > **Warning**: If you need to setup a default route, it's recommended to use the `network.GatewayNetwork` resource instead.
        """
        return pulumi.get(self, "push_default_route")

    @push_default_route.setter
    def push_default_route(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "push_default_route", value)

    @_builtins.property
    @pulumi.getter(name="pushDnsServer")
    def push_dns_server(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the gateway should push custom DNS servers to clients. This allows for instance hostname > IP resolution. Defaults to `true`.
        """
        return pulumi.get(self, "push_dns_server")

    @push_dns_server.setter
    def push_dns_server(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "push_dns_server", value)

    @_builtins.property
    @pulumi.getter(name="rebindTimer")
    def rebind_timer(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        After how long, in seconds, a DHCP client will query for a new lease if previous renews fail. Must be 30s lower than `valid_lifetime`. Defaults to 51m (3060s).
        """
        return pulumi.get(self, "rebind_timer")

    @rebind_timer.setter
    def rebind_timer(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "rebind_timer", value)

    @_builtins.property
    @pulumi.getter(name="renewTimer")
    def renew_timer(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        After how long, in seconds, a renewal will be attempted. Must be 30s lower than `rebind_timer`. Defaults to 50m (3000s).
        """
        return pulumi.get(self, "renew_timer")

    @renew_timer.setter
    def renew_timer(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "renew_timer", value)

    @_builtins.property
    @pulumi.getter(name="validLifetime")
    def valid_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How long, in seconds, DHCP entries will be valid. Defaults to 1h (3600s).
        """
        return pulumi.get(self, "valid_lifetime")

    @valid_lifetime.setter
    def valid_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "valid_lifetime", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the Public Gateway DHCP configuration should be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


@pulumi.input_type
class _VpcPublicGatewayDhcpState:
    def __init__(__self__, *,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_local_name: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_searches: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dns_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 enable_dynamic: Optional[pulumi.Input[_builtins.bool]] = None,
                 organization_id: Optional[pulumi.Input[_builtins.str]] = None,
                 pool_high: Optional[pulumi.Input[_builtins.str]] = None,
                 pool_low: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 push_default_route: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_dns_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 rebind_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 renew_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 subnet: Optional[pulumi.Input[_builtins.str]] = None,
                 updated_at: Optional[pulumi.Input[_builtins.str]] = None,
                 valid_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering VpcPublicGatewayDhcp resources.
        :param pulumi.Input[_builtins.str] address: The IP address of the DHCP server. This will be the gateway's address in the Private Network.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the Public Gateway DHCP configuration.
        :param pulumi.Input[_builtins.str] dns_local_name: TLD given to hostnames in the Private Network. Allowed characters are `a-z0-9-.`. Defaults to the slugified Private Network name if created along a GatewayNetwork, or else to `priv`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_searches: Additional DNS search paths
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_servers_overrides: Override the DNS server list pushed to DHCP clients, instead of the gateway itself.
        :param pulumi.Input[_builtins.bool] enable_dynamic: Whether to enable dynamic pooling of IPs. By turning the dynamic pool off, only pre-existing DHCP reservations will be handed out. Defaults to `true`.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the Public Gateway DHCP config is associated with.
        :param pulumi.Input[_builtins.str] pool_high: High IP (excluded) of the dynamic address pool. Defaults to the last address of the subnet.
        :param pulumi.Input[_builtins.str] pool_low: Low IP (included) of the dynamic address pool. Defaults to the second address of the subnet.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Public Gateway DHCP configuration is associated with.
        :param pulumi.Input[_builtins.bool] push_default_route: Whether the gateway should push a default route to DHCP clients or only hand out IPs. Defaults to `true`.
               
               > **Warning**: If you need to setup a default route, it's recommended to use the `network.GatewayNetwork` resource instead.
        :param pulumi.Input[_builtins.bool] push_dns_server: Whether the gateway should push custom DNS servers to clients. This allows for instance hostname > IP resolution. Defaults to `true`.
        :param pulumi.Input[_builtins.int] rebind_timer: After how long, in seconds, a DHCP client will query for a new lease if previous renews fail. Must be 30s lower than `valid_lifetime`. Defaults to 51m (3060s).
        :param pulumi.Input[_builtins.int] renew_timer: After how long, in seconds, a renewal will be attempted. Must be 30s lower than `rebind_timer`. Defaults to 50m (3000s).
        :param pulumi.Input[_builtins.str] subnet: The subnet to associate with the Public Gateway DHCP configuration.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the Public Gateway DHCP configuration.
        :param pulumi.Input[_builtins.int] valid_lifetime: How long, in seconds, DHCP entries will be valid. Defaults to 1h (3600s).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Public Gateway DHCP configuration should be created.
        """
        if address is not None:
            pulumi.set(__self__, "address", address)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if dns_local_name is not None:
            pulumi.set(__self__, "dns_local_name", dns_local_name)
        if dns_searches is not None:
            pulumi.set(__self__, "dns_searches", dns_searches)
        if dns_servers_overrides is not None:
            pulumi.set(__self__, "dns_servers_overrides", dns_servers_overrides)
        if enable_dynamic is not None:
            pulumi.set(__self__, "enable_dynamic", enable_dynamic)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if pool_high is not None:
            pulumi.set(__self__, "pool_high", pool_high)
        if pool_low is not None:
            pulumi.set(__self__, "pool_low", pool_low)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if push_default_route is not None:
            pulumi.set(__self__, "push_default_route", push_default_route)
        if push_dns_server is not None:
            pulumi.set(__self__, "push_dns_server", push_dns_server)
        if rebind_timer is not None:
            pulumi.set(__self__, "rebind_timer", rebind_timer)
        if renew_timer is not None:
            pulumi.set(__self__, "renew_timer", renew_timer)
        if subnet is not None:
            pulumi.set(__self__, "subnet", subnet)
        if updated_at is not None:
            pulumi.set(__self__, "updated_at", updated_at)
        if valid_lifetime is not None:
            pulumi.set(__self__, "valid_lifetime", valid_lifetime)
        if zone is not None:
            pulumi.set(__self__, "zone", zone)

    @_builtins.property
    @pulumi.getter
    def address(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The IP address of the DHCP server. This will be the gateway's address in the Private Network.
        """
        return pulumi.get(self, "address")

    @address.setter
    def address(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "address", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the creation of the Public Gateway DHCP configuration.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="dnsLocalName")
    def dns_local_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        TLD given to hostnames in the Private Network. Allowed characters are `a-z0-9-.`. Defaults to the slugified Private Network name if created along a GatewayNetwork, or else to `priv`.
        """
        return pulumi.get(self, "dns_local_name")

    @dns_local_name.setter
    def dns_local_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dns_local_name", value)

    @_builtins.property
    @pulumi.getter(name="dnsSearches")
    def dns_searches(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Additional DNS search paths
        """
        return pulumi.get(self, "dns_searches")

    @dns_searches.setter
    def dns_searches(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dns_searches", value)

    @_builtins.property
    @pulumi.getter(name="dnsServersOverrides")
    def dns_servers_overrides(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Override the DNS server list pushed to DHCP clients, instead of the gateway itself.
        """
        return pulumi.get(self, "dns_servers_overrides")

    @dns_servers_overrides.setter
    def dns_servers_overrides(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "dns_servers_overrides", value)

    @_builtins.property
    @pulumi.getter(name="enableDynamic")
    def enable_dynamic(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether to enable dynamic pooling of IPs. By turning the dynamic pool off, only pre-existing DHCP reservations will be handed out. Defaults to `true`.
        """
        return pulumi.get(self, "enable_dynamic")

    @enable_dynamic.setter
    def enable_dynamic(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "enable_dynamic", value)

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Organization ID the Public Gateway DHCP config is associated with.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "organization_id", value)

    @_builtins.property
    @pulumi.getter(name="poolHigh")
    def pool_high(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        High IP (excluded) of the dynamic address pool. Defaults to the last address of the subnet.
        """
        return pulumi.get(self, "pool_high")

    @pool_high.setter
    def pool_high(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pool_high", value)

    @_builtins.property
    @pulumi.getter(name="poolLow")
    def pool_low(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Low IP (included) of the dynamic address pool. Defaults to the second address of the subnet.
        """
        return pulumi.get(self, "pool_low")

    @pool_low.setter
    def pool_low(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "pool_low", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `project_id`) The ID of the Project the Public Gateway DHCP configuration is associated with.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="pushDefaultRoute")
    def push_default_route(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the gateway should push a default route to DHCP clients or only hand out IPs. Defaults to `true`.

        > **Warning**: If you need to setup a default route, it's recommended to use the `network.GatewayNetwork` resource instead.
        """
        return pulumi.get(self, "push_default_route")

    @push_default_route.setter
    def push_default_route(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "push_default_route", value)

    @_builtins.property
    @pulumi.getter(name="pushDnsServer")
    def push_dns_server(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the gateway should push custom DNS servers to clients. This allows for instance hostname > IP resolution. Defaults to `true`.
        """
        return pulumi.get(self, "push_dns_server")

    @push_dns_server.setter
    def push_dns_server(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "push_dns_server", value)

    @_builtins.property
    @pulumi.getter(name="rebindTimer")
    def rebind_timer(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        After how long, in seconds, a DHCP client will query for a new lease if previous renews fail. Must be 30s lower than `valid_lifetime`. Defaults to 51m (3060s).
        """
        return pulumi.get(self, "rebind_timer")

    @rebind_timer.setter
    def rebind_timer(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "rebind_timer", value)

    @_builtins.property
    @pulumi.getter(name="renewTimer")
    def renew_timer(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        After how long, in seconds, a renewal will be attempted. Must be 30s lower than `rebind_timer`. Defaults to 50m (3000s).
        """
        return pulumi.get(self, "renew_timer")

    @renew_timer.setter
    def renew_timer(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "renew_timer", value)

    @_builtins.property
    @pulumi.getter
    def subnet(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The subnet to associate with the Public Gateway DHCP configuration.
        """
        return pulumi.get(self, "subnet")

    @subnet.setter
    def subnet(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "subnet", value)

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The date and time of the last update of the Public Gateway DHCP configuration.
        """
        return pulumi.get(self, "updated_at")

    @updated_at.setter
    def updated_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "updated_at", value)

    @_builtins.property
    @pulumi.getter(name="validLifetime")
    def valid_lifetime(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        How long, in seconds, DHCP entries will be valid. Defaults to 1h (3600s).
        """
        return pulumi.get(self, "valid_lifetime")

    @valid_lifetime.setter
    def valid_lifetime(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "valid_lifetime", value)

    @_builtins.property
    @pulumi.getter
    def zone(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        `zone`) The zone in which the Public Gateway DHCP configuration should be created.
        """
        return pulumi.get(self, "zone")

    @zone.setter
    def zone(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "zone", value)


warnings.warn("""scaleway.index/vpcpublicgatewaydhcp.VpcPublicGatewayDhcp has been deprecated in favor of scaleway.network/publicgatewaydhcp.PublicGatewayDhcp""", DeprecationWarning)


@pulumi.type_token("scaleway:index/vpcPublicGatewayDhcp:VpcPublicGatewayDhcp")
class VpcPublicGatewayDhcp(pulumi.CustomResource):
    warnings.warn("""scaleway.index/vpcpublicgatewaydhcp.VpcPublicGatewayDhcp has been deprecated in favor of scaleway.network/publicgatewaydhcp.PublicGatewayDhcp""", DeprecationWarning)

    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_local_name: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_searches: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dns_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 enable_dynamic: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_high: Optional[pulumi.Input[_builtins.str]] = None,
                 pool_low: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 push_default_route: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_dns_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 rebind_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 renew_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 subnet: Optional[pulumi.Input[_builtins.str]] = None,
                 valid_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        > **Important:**  The resource `network.PublicGatewayDhcp` has been deprecated and will no longer be supported.
        In 2023, DHCP functionality was moved from Public Gateways to Private Networks, DHCP resources are now no longer needed.
        For more information, please refer to the dedicated guide.

        Creates and manages Scaleway VPC Public Gateway DHCP configurations.
        For more information, see the [API documentation](https://www.scaleway.com/en/developers/api/public-gateway/#dhcp-c05544).

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.PublicGatewayDhcp("main", subnet="192.168.1.0/24")
        ```

        ## Import

        Public Gateway DHCP configuration can be imported using `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/vpcPublicGatewayDhcp:VpcPublicGatewayDhcp main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address: The IP address of the DHCP server. This will be the gateway's address in the Private Network.
        :param pulumi.Input[_builtins.str] dns_local_name: TLD given to hostnames in the Private Network. Allowed characters are `a-z0-9-.`. Defaults to the slugified Private Network name if created along a GatewayNetwork, or else to `priv`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_searches: Additional DNS search paths
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_servers_overrides: Override the DNS server list pushed to DHCP clients, instead of the gateway itself.
        :param pulumi.Input[_builtins.bool] enable_dynamic: Whether to enable dynamic pooling of IPs. By turning the dynamic pool off, only pre-existing DHCP reservations will be handed out. Defaults to `true`.
        :param pulumi.Input[_builtins.str] pool_high: High IP (excluded) of the dynamic address pool. Defaults to the last address of the subnet.
        :param pulumi.Input[_builtins.str] pool_low: Low IP (included) of the dynamic address pool. Defaults to the second address of the subnet.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Public Gateway DHCP configuration is associated with.
        :param pulumi.Input[_builtins.bool] push_default_route: Whether the gateway should push a default route to DHCP clients or only hand out IPs. Defaults to `true`.
               
               > **Warning**: If you need to setup a default route, it's recommended to use the `network.GatewayNetwork` resource instead.
        :param pulumi.Input[_builtins.bool] push_dns_server: Whether the gateway should push custom DNS servers to clients. This allows for instance hostname > IP resolution. Defaults to `true`.
        :param pulumi.Input[_builtins.int] rebind_timer: After how long, in seconds, a DHCP client will query for a new lease if previous renews fail. Must be 30s lower than `valid_lifetime`. Defaults to 51m (3060s).
        :param pulumi.Input[_builtins.int] renew_timer: After how long, in seconds, a renewal will be attempted. Must be 30s lower than `rebind_timer`. Defaults to 50m (3000s).
        :param pulumi.Input[_builtins.str] subnet: The subnet to associate with the Public Gateway DHCP configuration.
        :param pulumi.Input[_builtins.int] valid_lifetime: How long, in seconds, DHCP entries will be valid. Defaults to 1h (3600s).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Public Gateway DHCP configuration should be created.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpcPublicGatewayDhcpArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        > **Important:**  The resource `network.PublicGatewayDhcp` has been deprecated and will no longer be supported.
        In 2023, DHCP functionality was moved from Public Gateways to Private Networks, DHCP resources are now no longer needed.
        For more information, please refer to the dedicated guide.

        Creates and manages Scaleway VPC Public Gateway DHCP configurations.
        For more information, see the [API documentation](https://www.scaleway.com/en/developers/api/public-gateway/#dhcp-c05544).

        ## Example Usage

        ```python
        import pulumi
        import pulumiverse_scaleway as scaleway

        main = scaleway.network.PublicGatewayDhcp("main", subnet="192.168.1.0/24")
        ```

        ## Import

        Public Gateway DHCP configuration can be imported using `{zone}/{id}`, e.g.

        bash

        ```sh
        $ pulumi import scaleway:index/vpcPublicGatewayDhcp:VpcPublicGatewayDhcp main fr-par-1/11111111-1111-1111-1111-111111111111
        ```

        :param str resource_name: The name of the resource.
        :param VpcPublicGatewayDhcpArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpcPublicGatewayDhcpArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 address: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_local_name: Optional[pulumi.Input[_builtins.str]] = None,
                 dns_searches: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 dns_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 enable_dynamic: Optional[pulumi.Input[_builtins.bool]] = None,
                 pool_high: Optional[pulumi.Input[_builtins.str]] = None,
                 pool_low: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 push_default_route: Optional[pulumi.Input[_builtins.bool]] = None,
                 push_dns_server: Optional[pulumi.Input[_builtins.bool]] = None,
                 rebind_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 renew_timer: Optional[pulumi.Input[_builtins.int]] = None,
                 subnet: Optional[pulumi.Input[_builtins.str]] = None,
                 valid_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
                 zone: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        pulumi.log.warn("""VpcPublicGatewayDhcp is deprecated: scaleway.index/vpcpublicgatewaydhcp.VpcPublicGatewayDhcp has been deprecated in favor of scaleway.network/publicgatewaydhcp.PublicGatewayDhcp""")
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpcPublicGatewayDhcpArgs.__new__(VpcPublicGatewayDhcpArgs)

            __props__.__dict__["address"] = address
            __props__.__dict__["dns_local_name"] = dns_local_name
            __props__.__dict__["dns_searches"] = dns_searches
            __props__.__dict__["dns_servers_overrides"] = dns_servers_overrides
            __props__.__dict__["enable_dynamic"] = enable_dynamic
            __props__.__dict__["pool_high"] = pool_high
            __props__.__dict__["pool_low"] = pool_low
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["push_default_route"] = push_default_route
            __props__.__dict__["push_dns_server"] = push_dns_server
            __props__.__dict__["rebind_timer"] = rebind_timer
            __props__.__dict__["renew_timer"] = renew_timer
            if subnet is None and not opts.urn:
                raise TypeError("Missing required property 'subnet'")
            __props__.__dict__["subnet"] = subnet
            __props__.__dict__["valid_lifetime"] = valid_lifetime
            __props__.__dict__["zone"] = zone
            __props__.__dict__["created_at"] = None
            __props__.__dict__["organization_id"] = None
            __props__.__dict__["updated_at"] = None
        super(VpcPublicGatewayDhcp, __self__).__init__(
            'scaleway:index/vpcPublicGatewayDhcp:VpcPublicGatewayDhcp',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            address: Optional[pulumi.Input[_builtins.str]] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            dns_local_name: Optional[pulumi.Input[_builtins.str]] = None,
            dns_searches: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            dns_servers_overrides: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            enable_dynamic: Optional[pulumi.Input[_builtins.bool]] = None,
            organization_id: Optional[pulumi.Input[_builtins.str]] = None,
            pool_high: Optional[pulumi.Input[_builtins.str]] = None,
            pool_low: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            push_default_route: Optional[pulumi.Input[_builtins.bool]] = None,
            push_dns_server: Optional[pulumi.Input[_builtins.bool]] = None,
            rebind_timer: Optional[pulumi.Input[_builtins.int]] = None,
            renew_timer: Optional[pulumi.Input[_builtins.int]] = None,
            subnet: Optional[pulumi.Input[_builtins.str]] = None,
            updated_at: Optional[pulumi.Input[_builtins.str]] = None,
            valid_lifetime: Optional[pulumi.Input[_builtins.int]] = None,
            zone: Optional[pulumi.Input[_builtins.str]] = None) -> 'VpcPublicGatewayDhcp':
        """
        Get an existing VpcPublicGatewayDhcp resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] address: The IP address of the DHCP server. This will be the gateway's address in the Private Network.
        :param pulumi.Input[_builtins.str] created_at: The date and time of the creation of the Public Gateway DHCP configuration.
        :param pulumi.Input[_builtins.str] dns_local_name: TLD given to hostnames in the Private Network. Allowed characters are `a-z0-9-.`. Defaults to the slugified Private Network name if created along a GatewayNetwork, or else to `priv`.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_searches: Additional DNS search paths
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] dns_servers_overrides: Override the DNS server list pushed to DHCP clients, instead of the gateway itself.
        :param pulumi.Input[_builtins.bool] enable_dynamic: Whether to enable dynamic pooling of IPs. By turning the dynamic pool off, only pre-existing DHCP reservations will be handed out. Defaults to `true`.
        :param pulumi.Input[_builtins.str] organization_id: The Organization ID the Public Gateway DHCP config is associated with.
        :param pulumi.Input[_builtins.str] pool_high: High IP (excluded) of the dynamic address pool. Defaults to the last address of the subnet.
        :param pulumi.Input[_builtins.str] pool_low: Low IP (included) of the dynamic address pool. Defaults to the second address of the subnet.
        :param pulumi.Input[_builtins.str] project_id: `project_id`) The ID of the Project the Public Gateway DHCP configuration is associated with.
        :param pulumi.Input[_builtins.bool] push_default_route: Whether the gateway should push a default route to DHCP clients or only hand out IPs. Defaults to `true`.
               
               > **Warning**: If you need to setup a default route, it's recommended to use the `network.GatewayNetwork` resource instead.
        :param pulumi.Input[_builtins.bool] push_dns_server: Whether the gateway should push custom DNS servers to clients. This allows for instance hostname > IP resolution. Defaults to `true`.
        :param pulumi.Input[_builtins.int] rebind_timer: After how long, in seconds, a DHCP client will query for a new lease if previous renews fail. Must be 30s lower than `valid_lifetime`. Defaults to 51m (3060s).
        :param pulumi.Input[_builtins.int] renew_timer: After how long, in seconds, a renewal will be attempted. Must be 30s lower than `rebind_timer`. Defaults to 50m (3000s).
        :param pulumi.Input[_builtins.str] subnet: The subnet to associate with the Public Gateway DHCP configuration.
        :param pulumi.Input[_builtins.str] updated_at: The date and time of the last update of the Public Gateway DHCP configuration.
        :param pulumi.Input[_builtins.int] valid_lifetime: How long, in seconds, DHCP entries will be valid. Defaults to 1h (3600s).
        :param pulumi.Input[_builtins.str] zone: `zone`) The zone in which the Public Gateway DHCP configuration should be created.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpcPublicGatewayDhcpState.__new__(_VpcPublicGatewayDhcpState)

        __props__.__dict__["address"] = address
        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["dns_local_name"] = dns_local_name
        __props__.__dict__["dns_searches"] = dns_searches
        __props__.__dict__["dns_servers_overrides"] = dns_servers_overrides
        __props__.__dict__["enable_dynamic"] = enable_dynamic
        __props__.__dict__["organization_id"] = organization_id
        __props__.__dict__["pool_high"] = pool_high
        __props__.__dict__["pool_low"] = pool_low
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["push_default_route"] = push_default_route
        __props__.__dict__["push_dns_server"] = push_dns_server
        __props__.__dict__["rebind_timer"] = rebind_timer
        __props__.__dict__["renew_timer"] = renew_timer
        __props__.__dict__["subnet"] = subnet
        __props__.__dict__["updated_at"] = updated_at
        __props__.__dict__["valid_lifetime"] = valid_lifetime
        __props__.__dict__["zone"] = zone
        return VpcPublicGatewayDhcp(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def address(self) -> pulumi.Output[_builtins.str]:
        """
        The IP address of the DHCP server. This will be the gateway's address in the Private Network.
        """
        return pulumi.get(self, "address")

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the creation of the Public Gateway DHCP configuration.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="dnsLocalName")
    def dns_local_name(self) -> pulumi.Output[_builtins.str]:
        """
        TLD given to hostnames in the Private Network. Allowed characters are `a-z0-9-.`. Defaults to the slugified Private Network name if created along a GatewayNetwork, or else to `priv`.
        """
        return pulumi.get(self, "dns_local_name")

    @_builtins.property
    @pulumi.getter(name="dnsSearches")
    def dns_searches(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Additional DNS search paths
        """
        return pulumi.get(self, "dns_searches")

    @_builtins.property
    @pulumi.getter(name="dnsServersOverrides")
    def dns_servers_overrides(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Override the DNS server list pushed to DHCP clients, instead of the gateway itself.
        """
        return pulumi.get(self, "dns_servers_overrides")

    @_builtins.property
    @pulumi.getter(name="enableDynamic")
    def enable_dynamic(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether to enable dynamic pooling of IPs. By turning the dynamic pool off, only pre-existing DHCP reservations will be handed out. Defaults to `true`.
        """
        return pulumi.get(self, "enable_dynamic")

    @_builtins.property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> pulumi.Output[_builtins.str]:
        """
        The Organization ID the Public Gateway DHCP config is associated with.
        """
        return pulumi.get(self, "organization_id")

    @_builtins.property
    @pulumi.getter(name="poolHigh")
    def pool_high(self) -> pulumi.Output[_builtins.str]:
        """
        High IP (excluded) of the dynamic address pool. Defaults to the last address of the subnet.
        """
        return pulumi.get(self, "pool_high")

    @_builtins.property
    @pulumi.getter(name="poolLow")
    def pool_low(self) -> pulumi.Output[_builtins.str]:
        """
        Low IP (included) of the dynamic address pool. Defaults to the second address of the subnet.
        """
        return pulumi.get(self, "pool_low")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        `project_id`) The ID of the Project the Public Gateway DHCP configuration is associated with.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter(name="pushDefaultRoute")
    def push_default_route(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the gateway should push a default route to DHCP clients or only hand out IPs. Defaults to `true`.

        > **Warning**: If you need to setup a default route, it's recommended to use the `network.GatewayNetwork` resource instead.
        """
        return pulumi.get(self, "push_default_route")

    @_builtins.property
    @pulumi.getter(name="pushDnsServer")
    def push_dns_server(self) -> pulumi.Output[_builtins.bool]:
        """
        Whether the gateway should push custom DNS servers to clients. This allows for instance hostname > IP resolution. Defaults to `true`.
        """
        return pulumi.get(self, "push_dns_server")

    @_builtins.property
    @pulumi.getter(name="rebindTimer")
    def rebind_timer(self) -> pulumi.Output[_builtins.int]:
        """
        After how long, in seconds, a DHCP client will query for a new lease if previous renews fail. Must be 30s lower than `valid_lifetime`. Defaults to 51m (3060s).
        """
        return pulumi.get(self, "rebind_timer")

    @_builtins.property
    @pulumi.getter(name="renewTimer")
    def renew_timer(self) -> pulumi.Output[_builtins.int]:
        """
        After how long, in seconds, a renewal will be attempted. Must be 30s lower than `rebind_timer`. Defaults to 50m (3000s).
        """
        return pulumi.get(self, "renew_timer")

    @_builtins.property
    @pulumi.getter
    def subnet(self) -> pulumi.Output[_builtins.str]:
        """
        The subnet to associate with the Public Gateway DHCP configuration.
        """
        return pulumi.get(self, "subnet")

    @_builtins.property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> pulumi.Output[_builtins.str]:
        """
        The date and time of the last update of the Public Gateway DHCP configuration.
        """
        return pulumi.get(self, "updated_at")

    @_builtins.property
    @pulumi.getter(name="validLifetime")
    def valid_lifetime(self) -> pulumi.Output[_builtins.int]:
        """
        How long, in seconds, DHCP entries will be valid. Defaults to 1h (3600s).
        """
        return pulumi.get(self, "valid_lifetime")

    @_builtins.property
    @pulumi.getter
    def zone(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        `zone`) The zone in which the Public Gateway DHCP configuration should be created.
        """
        return pulumi.get(self, "zone")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetOfferSubscriptionResult',
    'AwaitableGetOfferSubscriptionResult',
    'get_offer_subscription',
    'get_offer_subscription_output',
]

@pulumi.output_type
class GetOfferSubscriptionResult:
    """
    A collection of values returned by getOfferSubscription.
    """
    def __init__(__self__, cancellation_available_at=None, id=None, included_monthly_emails=None, max_custom_blocklists_per_domain=None, max_dedicated_ips=None, max_domains=None, max_webhooks_per_domain=None, offer_name=None, project_id=None, region=None, sla=None, subscribed_at=None):
        if cancellation_available_at and not isinstance(cancellation_available_at, str):
            raise TypeError("Expected argument 'cancellation_available_at' to be a str")
        pulumi.set(__self__, "cancellation_available_at", cancellation_available_at)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if included_monthly_emails and not isinstance(included_monthly_emails, int):
            raise TypeError("Expected argument 'included_monthly_emails' to be a int")
        pulumi.set(__self__, "included_monthly_emails", included_monthly_emails)
        if max_custom_blocklists_per_domain and not isinstance(max_custom_blocklists_per_domain, int):
            raise TypeError("Expected argument 'max_custom_blocklists_per_domain' to be a int")
        pulumi.set(__self__, "max_custom_blocklists_per_domain", max_custom_blocklists_per_domain)
        if max_dedicated_ips and not isinstance(max_dedicated_ips, int):
            raise TypeError("Expected argument 'max_dedicated_ips' to be a int")
        pulumi.set(__self__, "max_dedicated_ips", max_dedicated_ips)
        if max_domains and not isinstance(max_domains, int):
            raise TypeError("Expected argument 'max_domains' to be a int")
        pulumi.set(__self__, "max_domains", max_domains)
        if max_webhooks_per_domain and not isinstance(max_webhooks_per_domain, int):
            raise TypeError("Expected argument 'max_webhooks_per_domain' to be a int")
        pulumi.set(__self__, "max_webhooks_per_domain", max_webhooks_per_domain)
        if offer_name and not isinstance(offer_name, str):
            raise TypeError("Expected argument 'offer_name' to be a str")
        pulumi.set(__self__, "offer_name", offer_name)
        if project_id and not isinstance(project_id, str):
            raise TypeError("Expected argument 'project_id' to be a str")
        pulumi.set(__self__, "project_id", project_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)
        if sla and not isinstance(sla, float):
            raise TypeError("Expected argument 'sla' to be a float")
        pulumi.set(__self__, "sla", sla)
        if subscribed_at and not isinstance(subscribed_at, str):
            raise TypeError("Expected argument 'subscribed_at' to be a str")
        pulumi.set(__self__, "subscribed_at", subscribed_at)

    @_builtins.property
    @pulumi.getter(name="cancellationAvailableAt")
    def cancellation_available_at(self) -> _builtins.str:
        """
        The date and time when cancellation becomes available for the subscription.
        """
        return pulumi.get(self, "cancellation_available_at")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="includedMonthlyEmails")
    def included_monthly_emails(self) -> _builtins.int:
        """
        The number of emails included in the offer subscription per month.
        """
        return pulumi.get(self, "included_monthly_emails")

    @_builtins.property
    @pulumi.getter(name="maxCustomBlocklistsPerDomain")
    def max_custom_blocklists_per_domain(self) -> _builtins.int:
        """
        The maximum number of custom blocklists that can be associated with the offer subscription per domain.
        """
        return pulumi.get(self, "max_custom_blocklists_per_domain")

    @_builtins.property
    @pulumi.getter(name="maxDedicatedIps")
    def max_dedicated_ips(self) -> _builtins.int:
        """
        The maximum number of dedicated IPs that can be associated with the offer subscription.
        """
        return pulumi.get(self, "max_dedicated_ips")

    @_builtins.property
    @pulumi.getter(name="maxDomains")
    def max_domains(self) -> _builtins.int:
        """
        The maximum number of domains that can be associated with the offer subscription.
        """
        return pulumi.get(self, "max_domains")

    @_builtins.property
    @pulumi.getter(name="maxWebhooksPerDomain")
    def max_webhooks_per_domain(self) -> _builtins.int:
        """
        The maximum number of webhooks that can be associated with the offer subscription per domain.
        """
        return pulumi.get(self, "max_webhooks_per_domain")

    @_builtins.property
    @pulumi.getter(name="offerName")
    def offer_name(self) -> _builtins.str:
        """
        The name of the offer associated with the subscription (e.g., `scale`).
        """
        return pulumi.get(self, "offer_name")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> _builtins.str:
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")

    @_builtins.property
    @pulumi.getter
    def sla(self) -> _builtins.float:
        """
        The Service Level Agreement (SLA) percentage of the offer subscription.
        """
        return pulumi.get(self, "sla")

    @_builtins.property
    @pulumi.getter(name="subscribedAt")
    def subscribed_at(self) -> _builtins.str:
        """
        The date and time of the subscription.
        """
        return pulumi.get(self, "subscribed_at")


class AwaitableGetOfferSubscriptionResult(GetOfferSubscriptionResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOfferSubscriptionResult(
            cancellation_available_at=self.cancellation_available_at,
            id=self.id,
            included_monthly_emails=self.included_monthly_emails,
            max_custom_blocklists_per_domain=self.max_custom_blocklists_per_domain,
            max_dedicated_ips=self.max_dedicated_ips,
            max_domains=self.max_domains,
            max_webhooks_per_domain=self.max_webhooks_per_domain,
            offer_name=self.offer_name,
            project_id=self.project_id,
            region=self.region,
            sla=self.sla,
            subscribed_at=self.subscribed_at)


def get_offer_subscription(project_id: Optional[_builtins.str] = None,
                           region: Optional[_builtins.str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOfferSubscriptionResult:
    """
    Gets information about a transactional email offer subscription.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve offer subscription information
    test = scaleway.tem.get_offer_subscription()
    ```


    :param _builtins.str project_id: `project_id`) The ID of the project the offer subscription is associated with.
    :param _builtins.str region: `region`) The region where the offer subscription exists.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:tem/getOfferSubscription:getOfferSubscription', __args__, opts=opts, typ=GetOfferSubscriptionResult).value

    return AwaitableGetOfferSubscriptionResult(
        cancellation_available_at=pulumi.get(__ret__, 'cancellation_available_at'),
        id=pulumi.get(__ret__, 'id'),
        included_monthly_emails=pulumi.get(__ret__, 'included_monthly_emails'),
        max_custom_blocklists_per_domain=pulumi.get(__ret__, 'max_custom_blocklists_per_domain'),
        max_dedicated_ips=pulumi.get(__ret__, 'max_dedicated_ips'),
        max_domains=pulumi.get(__ret__, 'max_domains'),
        max_webhooks_per_domain=pulumi.get(__ret__, 'max_webhooks_per_domain'),
        offer_name=pulumi.get(__ret__, 'offer_name'),
        project_id=pulumi.get(__ret__, 'project_id'),
        region=pulumi.get(__ret__, 'region'),
        sla=pulumi.get(__ret__, 'sla'),
        subscribed_at=pulumi.get(__ret__, 'subscribed_at'))
def get_offer_subscription_output(project_id: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                                  opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOfferSubscriptionResult]:
    """
    Gets information about a transactional email offer subscription.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Retrieve offer subscription information
    test = scaleway.tem.get_offer_subscription()
    ```


    :param _builtins.str project_id: `project_id`) The ID of the project the offer subscription is associated with.
    :param _builtins.str region: `region`) The region where the offer subscription exists.
    """
    __args__ = dict()
    __args__['projectId'] = project_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:tem/getOfferSubscription:getOfferSubscription', __args__, opts=opts, typ=GetOfferSubscriptionResult)
    return __ret__.apply(lambda __response__: GetOfferSubscriptionResult(
        cancellation_available_at=pulumi.get(__response__, 'cancellation_available_at'),
        id=pulumi.get(__response__, 'id'),
        included_monthly_emails=pulumi.get(__response__, 'included_monthly_emails'),
        max_custom_blocklists_per_domain=pulumi.get(__response__, 'max_custom_blocklists_per_domain'),
        max_dedicated_ips=pulumi.get(__response__, 'max_dedicated_ips'),
        max_domains=pulumi.get(__response__, 'max_domains'),
        max_webhooks_per_domain=pulumi.get(__response__, 'max_webhooks_per_domain'),
        offer_name=pulumi.get(__response__, 'offer_name'),
        project_id=pulumi.get(__response__, 'project_id'),
        region=pulumi.get(__response__, 'region'),
        sla=pulumi.get(__response__, 'sla'),
        subscribed_at=pulumi.get(__response__, 'subscribed_at')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetAclResult',
    'AwaitableGetAclResult',
    'get_acl',
    'get_acl_output',
]

@pulumi.output_type
class GetAclResult:
    """
    A collection of values returned by getAcl.
    """
    def __init__(__self__, acl_rules=None, id=None, instance_id=None, region=None):
        if acl_rules and not isinstance(acl_rules, list):
            raise TypeError("Expected argument 'acl_rules' to be a list")
        pulumi.set(__self__, "acl_rules", acl_rules)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if region and not isinstance(region, str):
            raise TypeError("Expected argument 'region' to be a str")
        pulumi.set(__self__, "region", region)

    @_builtins.property
    @pulumi.getter(name="aclRules")
    def acl_rules(self) -> Sequence['outputs.GetAclAclRuleResult']:
        """
        A list of ACLs rules (structure is described below)
        """
        return pulumi.get(self, "acl_rules")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> _builtins.str:
        return pulumi.get(self, "instance_id")

    @_builtins.property
    @pulumi.getter
    def region(self) -> Optional[_builtins.str]:
        return pulumi.get(self, "region")


class AwaitableGetAclResult(GetAclResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAclResult(
            acl_rules=self.acl_rules,
            id=self.id,
            instance_id=self.instance_id,
            region=self.region)


def get_acl(instance_id: Optional[_builtins.str] = None,
            region: Optional[_builtins.str] = None,
            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAclResult:
    """
    Gets information about the Database Instance network Access Control List.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get the database ACL for the instance id 11111111-1111-1111-1111-111111111111 located in the default region e.g: fr-par
    my_acl = scaleway.databases.get_acl(instance_id="11111111-1111-1111-1111-111111111111")
    ```


    :param _builtins.str instance_id: The RDB instance ID.
    :param _builtins.str region: `region`) The region in which the Database Instance should be created.
    """
    __args__ = dict()
    __args__['instanceId'] = instance_id
    __args__['region'] = region
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('scaleway:databases/getAcl:getAcl', __args__, opts=opts, typ=GetAclResult).value

    return AwaitableGetAclResult(
        acl_rules=pulumi.get(__ret__, 'acl_rules'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        region=pulumi.get(__ret__, 'region'))
def get_acl_output(instance_id: Optional[pulumi.Input[_builtins.str]] = None,
                   region: Optional[pulumi.Input[Optional[_builtins.str]]] = None,
                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetAclResult]:
    """
    Gets information about the Database Instance network Access Control List.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_scaleway as scaleway

    # Get the database ACL for the instance id 11111111-1111-1111-1111-111111111111 located in the default region e.g: fr-par
    my_acl = scaleway.databases.get_acl(instance_id="11111111-1111-1111-1111-111111111111")
    ```


    :param _builtins.str instance_id: The RDB instance ID.
    :param _builtins.str region: `region`) The region in which the Database Instance should be created.
    """
    __args__ = dict()
    __args__['instanceId'] = instance_id
    __args__['region'] = region
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('scaleway:databases/getAcl:getAcl', __args__, opts=opts, typ=GetAclResult)
    return __ret__.apply(lambda __response__: GetAclResult(
        acl_rules=pulumi.get(__response__, 'acl_rules'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        region=pulumi.get(__response__, 'region')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from . import _utilities
import typing
# Export this package's modules as members:
from .account_project import *
from .account_ssh_key import *
from .apple_silicon_server import *
from .baremetal_server import *
from .block_snapshot import *
from .block_volume import *
from .cockpit import *
from .cockpit_alert_manager import *
from .cockpit_grafana_user import *
from .cockpit_source import *
from .cockpit_token import *
from .container import *
from .container_cron import *
from .container_domain import *
from .container_namespace import *
from .container_token import *
from .container_trigger import *
from .database import *
from .database_acl import *
from .database_backup import *
from .database_instance import *
from .database_privilege import *
from .database_read_replica import *
from .database_user import *
from .domain_record import *
from .domain_zone import *
from .edge_services_backend_stage import *
from .edge_services_cache_stage import *
from .edge_services_dns_stage import *
from .edge_services_head_stage import *
from .edge_services_pipeline import *
from .edge_services_plan import *
from .edge_services_route_stage import *
from .edge_services_tls_stage import *
from .edge_services_waf_stage import *
from .file_filesystem import *
from .flexible_ip import *
from .flexible_ip_mac_address import *
from .function import *
from .function_cron import *
from .function_domain import *
from .function_namespace import *
from .function_token import *
from .function_trigger import *
from .get_account_project import *
from .get_account_ssh_key import *
from .get_availability_zones import *
from .get_baremetal_offer import *
from .get_baremetal_option import *
from .get_baremetal_os import *
from .get_baremetal_server import *
from .get_billing_consumptions import *
from .get_billing_invoices import *
from .get_block_snapshot import *
from .get_block_volume import *
from .get_cockpit import *
from .get_cockpit_source import *
from .get_config import *
from .get_container import *
from .get_container_namespace import *
from .get_database import *
from .get_database_acl import *
from .get_database_backup import *
from .get_database_instance import *
from .get_database_privilege import *
from .get_domain_record import *
from .get_domain_zone import *
from .get_flexible_ip import *
from .get_flexible_ips import *
from .get_function import *
from .get_function_namespace import *
from .get_iam_api_key import *
from .get_iam_application import *
from .get_iam_group import *
from .get_iam_ssh_key import *
from .get_iam_user import *
from .get_instance_image import *
from .get_instance_ip import *
from .get_instance_placement_group import *
from .get_instance_private_nic import *
from .get_instance_security_group import *
from .get_instance_server import *
from .get_instance_servers import *
from .get_instance_snapshot import *
from .get_instance_volume import *
from .get_iot_device import *
from .get_iot_hub import *
from .get_ipam_ip import *
from .get_ipam_ips import *
from .get_k8s_version import *
from .get_kubernetes_cluster import *
from .get_kubernetes_node_pool import *
from .get_lb_acls import *
from .get_lb_backend import *
from .get_lb_backends import *
from .get_lb_frontend import *
from .get_lb_frontends import *
from .get_lb_ips import *
from .get_lb_route import *
from .get_lb_routes import *
from .get_lbs import *
from .get_loadbalancer import *
from .get_loadbalancer_certificate import *
from .get_loadbalancer_ip import *
from .get_marketplace_image import *
from .get_mnq_sns import *
from .get_mnq_sqs import *
from .get_mongo_db_instance import *
from .get_object_bucket import *
from .get_object_bucket_policy import *
from .get_redis_cluster import *
from .get_registry_image import *
from .get_registry_image_tag import *
from .get_registry_namespace import *
from .get_secret import *
from .get_secret_version import *
from .get_tem_domain import *
from .get_vpc import *
from .get_vpc_gateway_network import *
from .get_vpc_private_network import *
from .get_vpc_public_gateway import *
from .get_vpc_public_gateway_dhcp import *
from .get_vpc_public_gateway_dhcp_reservation import *
from .get_vpc_public_gateway_ip import *
from .get_vpc_public_pat_rule import *
from .get_vpc_routes import *
from .get_vpcs import *
from .get_web_host_offer import *
from .get_webhosting import *
from .iam_api_key import *
from .iam_application import *
from .iam_group import *
from .iam_group_membership import *
from .iam_policy import *
from .iam_ssh_key import *
from .iam_user import *
from .inference_deployment import *
from .instance_image import *
from .instance_ip import *
from .instance_ip_reverse_dns import *
from .instance_placement_group import *
from .instance_private_nic import *
from .instance_security_group import *
from .instance_security_group_rules import *
from .instance_server import *
from .instance_snapshot import *
from .instance_user_data import *
from .instance_volume import *
from .iot_device import *
from .iot_hub import *
from .iot_network import *
from .iot_route import *
from .ipam_ip import *
from .ipam_ip_reverse_dns import *
from .job_definition import *
from .key_manager_key import *
from .kubernetes_cluster import *
from .kubernetes_node_pool import *
from .loadbalancer import *
from .loadbalancer_acl import *
from .loadbalancer_backend import *
from .loadbalancer_certificate import *
from .loadbalancer_frontend import *
from .loadbalancer_ip import *
from .loadbalancer_route import *
from .mnq_nats_account import *
from .mnq_nats_credentials import *
from .mnq_sns import *
from .mnq_sns_credentials import *
from .mnq_sns_topic import *
from .mnq_sns_topic_subscription import *
from .mnq_sqs import *
from .mnq_sqs_credentials import *
from .mnq_sqs_queue import *
from .mongo_db_instance import *
from .mongo_db_snapshot import *
from .object_bucket import *
from .object_bucket_acl import *
from .object_bucket_lock_configuration import *
from .object_bucket_policy import *
from .object_bucket_website_configuration import *
from .object_item import *
from .provider import *
from .rdb_snapshot import *
from .redis_cluster import *
from .registry_namespace import *
from .sdb_database import *
from .secret import *
from .secret_version import *
from .tem_domain import *
from .tem_domain_validation import *
from .tem_webhook import *
from .vpc import *
from .vpc_gateway_network import *
from .vpc_private_network import *
from .vpc_public_gateway import *
from .vpc_public_gateway_dhcp import *
from .vpc_public_gateway_dhcp_reservation import *
from .vpc_public_gateway_ip import *
from .vpc_public_gateway_ip_reverse_dns import *
from .vpc_public_gateway_pat_rule import *
from .vpc_route import *
from .webhosting import *
from ._inputs import *
from . import outputs

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumiverse_scaleway.account as __account
    account = __account
    import pulumiverse_scaleway.applesilicon as __applesilicon
    applesilicon = __applesilicon
    import pulumiverse_scaleway.autoscaling as __autoscaling
    autoscaling = __autoscaling
    import pulumiverse_scaleway.billing as __billing
    billing = __billing
    import pulumiverse_scaleway.block as __block
    block = __block
    import pulumiverse_scaleway.config as __config
    config = __config
    import pulumiverse_scaleway.containers as __containers
    containers = __containers
    import pulumiverse_scaleway.databases as __databases
    databases = __databases
    import pulumiverse_scaleway.domain as __domain
    domain = __domain
    import pulumiverse_scaleway.elasticmetal as __elasticmetal
    elasticmetal = __elasticmetal
    import pulumiverse_scaleway.functions as __functions
    functions = __functions
    import pulumiverse_scaleway.hosting as __hosting
    hosting = __hosting
    import pulumiverse_scaleway.iam as __iam
    iam = __iam
    import pulumiverse_scaleway.inference as __inference
    inference = __inference
    import pulumiverse_scaleway.instance as __instance
    instance = __instance
    import pulumiverse_scaleway.iot as __iot
    iot = __iot
    import pulumiverse_scaleway.ipam as __ipam
    ipam = __ipam
    import pulumiverse_scaleway.job as __job
    job = __job
    import pulumiverse_scaleway.kubernetes as __kubernetes
    kubernetes = __kubernetes
    import pulumiverse_scaleway.loadbalancers as __loadbalancers
    loadbalancers = __loadbalancers
    import pulumiverse_scaleway.mnq as __mnq
    mnq = __mnq
    import pulumiverse_scaleway.mongodb as __mongodb
    mongodb = __mongodb
    import pulumiverse_scaleway.network as __network
    network = __network
    import pulumiverse_scaleway.object as __object
    object = __object
    import pulumiverse_scaleway.observability as __observability
    observability = __observability
    import pulumiverse_scaleway.redis as __redis
    redis = __redis
    import pulumiverse_scaleway.registry as __registry
    registry = __registry
    import pulumiverse_scaleway.secrets as __secrets
    secrets = __secrets
    import pulumiverse_scaleway.tem as __tem
    tem = __tem
else:
    account = _utilities.lazy_import('pulumiverse_scaleway.account')
    applesilicon = _utilities.lazy_import('pulumiverse_scaleway.applesilicon')
    autoscaling = _utilities.lazy_import('pulumiverse_scaleway.autoscaling')
    billing = _utilities.lazy_import('pulumiverse_scaleway.billing')
    block = _utilities.lazy_import('pulumiverse_scaleway.block')
    config = _utilities.lazy_import('pulumiverse_scaleway.config')
    containers = _utilities.lazy_import('pulumiverse_scaleway.containers')
    databases = _utilities.lazy_import('pulumiverse_scaleway.databases')
    domain = _utilities.lazy_import('pulumiverse_scaleway.domain')
    elasticmetal = _utilities.lazy_import('pulumiverse_scaleway.elasticmetal')
    functions = _utilities.lazy_import('pulumiverse_scaleway.functions')
    hosting = _utilities.lazy_import('pulumiverse_scaleway.hosting')
    iam = _utilities.lazy_import('pulumiverse_scaleway.iam')
    inference = _utilities.lazy_import('pulumiverse_scaleway.inference')
    instance = _utilities.lazy_import('pulumiverse_scaleway.instance')
    iot = _utilities.lazy_import('pulumiverse_scaleway.iot')
    ipam = _utilities.lazy_import('pulumiverse_scaleway.ipam')
    job = _utilities.lazy_import('pulumiverse_scaleway.job')
    kubernetes = _utilities.lazy_import('pulumiverse_scaleway.kubernetes')
    loadbalancers = _utilities.lazy_import('pulumiverse_scaleway.loadbalancers')
    mnq = _utilities.lazy_import('pulumiverse_scaleway.mnq')
    mongodb = _utilities.lazy_import('pulumiverse_scaleway.mongodb')
    network = _utilities.lazy_import('pulumiverse_scaleway.network')
    object = _utilities.lazy_import('pulumiverse_scaleway.object')
    observability = _utilities.lazy_import('pulumiverse_scaleway.observability')
    redis = _utilities.lazy_import('pulumiverse_scaleway.redis')
    registry = _utilities.lazy_import('pulumiverse_scaleway.registry')
    secrets = _utilities.lazy_import('pulumiverse_scaleway.secrets')
    tem = _utilities.lazy_import('pulumiverse_scaleway.tem')

_utilities.register(
    resource_modules="""
[
 {
  "pkg": "scaleway",
  "mod": "account/project",
  "fqn": "pulumiverse_scaleway.account",
  "classes": {
   "scaleway:account/project:Project": "Project"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "account/sshKey",
  "fqn": "pulumiverse_scaleway.account",
  "classes": {
   "scaleway:account/sshKey:SshKey": "SshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "applesilicon/server",
  "fqn": "pulumiverse_scaleway.applesilicon",
  "classes": {
   "scaleway:applesilicon/server:Server": "Server"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "autoscaling/instanceGroup",
  "fqn": "pulumiverse_scaleway.autoscaling",
  "classes": {
   "scaleway:autoscaling/instanceGroup:InstanceGroup": "InstanceGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "autoscaling/instancePolicy",
  "fqn": "pulumiverse_scaleway.autoscaling",
  "classes": {
   "scaleway:autoscaling/instancePolicy:InstancePolicy": "InstancePolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "autoscaling/instanceTemplate",
  "fqn": "pulumiverse_scaleway.autoscaling",
  "classes": {
   "scaleway:autoscaling/instanceTemplate:InstanceTemplate": "InstanceTemplate"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "block/snapshot",
  "fqn": "pulumiverse_scaleway.block",
  "classes": {
   "scaleway:block/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "block/volume",
  "fqn": "pulumiverse_scaleway.block",
  "classes": {
   "scaleway:block/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/container",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/container:Container": "Container"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/cron",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/cron:Cron": "Cron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/domain",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/namespace",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/token",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/token:Token": "Token"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "containers/trigger",
  "fqn": "pulumiverse_scaleway.containers",
  "classes": {
   "scaleway:containers/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/acl",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/database",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/database:Database": "Database"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/databaseBackup",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/databaseBackup:DatabaseBackup": "DatabaseBackup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/instance",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/privilege",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/privilege:Privilege": "Privilege"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/readReplica",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/readReplica:ReadReplica": "ReadReplica"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/serverlessDatabase",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/serverlessDatabase:ServerlessDatabase": "ServerlessDatabase"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/snapshot",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "databases/user",
  "fqn": "pulumiverse_scaleway.databases",
  "classes": {
   "scaleway:databases/user:User": "User"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "domain/record",
  "fqn": "pulumiverse_scaleway.domain",
  "classes": {
   "scaleway:domain/record:Record": "Record"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "domain/registration",
  "fqn": "pulumiverse_scaleway.domain",
  "classes": {
   "scaleway:domain/registration:Registration": "Registration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "domain/zone",
  "fqn": "pulumiverse_scaleway.domain",
  "classes": {
   "scaleway:domain/zone:Zone": "Zone"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "elasticmetal/ip",
  "fqn": "pulumiverse_scaleway.elasticmetal",
  "classes": {
   "scaleway:elasticmetal/ip:Ip": "Ip"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "elasticmetal/ipMacAddress",
  "fqn": "pulumiverse_scaleway.elasticmetal",
  "classes": {
   "scaleway:elasticmetal/ipMacAddress:IpMacAddress": "IpMacAddress"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "elasticmetal/server",
  "fqn": "pulumiverse_scaleway.elasticmetal",
  "classes": {
   "scaleway:elasticmetal/server:Server": "Server"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/cron",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/cron:Cron": "Cron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/domain",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/function",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/function:Function": "Function"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/namespace",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/token",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/token:Token": "Token"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "functions/trigger",
  "fqn": "pulumiverse_scaleway.functions",
  "classes": {
   "scaleway:functions/trigger:Trigger": "Trigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "hosting/hosting",
  "fqn": "pulumiverse_scaleway.hosting",
  "classes": {
   "scaleway:hosting/hosting:Hosting": "Hosting"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/apiKey",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/apiKey:ApiKey": "ApiKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/application",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/application:Application": "Application"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/group",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/group:Group": "Group"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/groupMembership",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/groupMembership:GroupMembership": "GroupMembership"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/policy",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/policy:Policy": "Policy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/sshKey",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/sshKey:SshKey": "SshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iam/user",
  "fqn": "pulumiverse_scaleway.iam",
  "classes": {
   "scaleway:iam/user:User": "User"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/accountProject",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/accountProject:AccountProject": "AccountProject"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/accountSshKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/accountSshKey:AccountSshKey": "AccountSshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/appleSiliconServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/appleSiliconServer:AppleSiliconServer": "AppleSiliconServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/baremetalServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/baremetalServer:BaremetalServer": "BaremetalServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/blockSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/blockSnapshot:BlockSnapshot": "BlockSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/blockVolume",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/blockVolume:BlockVolume": "BlockVolume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpit",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpit:Cockpit": "Cockpit"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitAlertManager",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitAlertManager:CockpitAlertManager": "CockpitAlertManager"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitGrafanaUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitGrafanaUser:CockpitGrafanaUser": "CockpitGrafanaUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitSource",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitSource:CockpitSource": "CockpitSource"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/cockpitToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/cockpitToken:CockpitToken": "CockpitToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/container",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/container:Container": "Container"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerCron",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerCron:ContainerCron": "ContainerCron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerDomain:ContainerDomain": "ContainerDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerNamespace:ContainerNamespace": "ContainerNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerToken:ContainerToken": "ContainerToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/containerTrigger",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/containerTrigger:ContainerTrigger": "ContainerTrigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/database",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/database:Database": "Database"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseAcl:DatabaseAcl": "DatabaseAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseBackup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseBackup:DatabaseBackup": "DatabaseBackup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseInstance",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseInstance:DatabaseInstance": "DatabaseInstance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databasePrivilege",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databasePrivilege:DatabasePrivilege": "DatabasePrivilege"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseReadReplica",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseReadReplica:DatabaseReadReplica": "DatabaseReadReplica"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/databaseUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/databaseUser:DatabaseUser": "DatabaseUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/domainRecord",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/domainRecord:DomainRecord": "DomainRecord"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/domainZone",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/domainZone:DomainZone": "DomainZone"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesBackendStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesBackendStage:EdgeServicesBackendStage": "EdgeServicesBackendStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesCacheStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesCacheStage:EdgeServicesCacheStage": "EdgeServicesCacheStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesDnsStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesDnsStage:EdgeServicesDnsStage": "EdgeServicesDnsStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesHeadStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesHeadStage:EdgeServicesHeadStage": "EdgeServicesHeadStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesPipeline",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesPipeline:EdgeServicesPipeline": "EdgeServicesPipeline"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesPlan",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesPlan:EdgeServicesPlan": "EdgeServicesPlan"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesRouteStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesRouteStage:EdgeServicesRouteStage": "EdgeServicesRouteStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesTlsStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesTlsStage:EdgeServicesTlsStage": "EdgeServicesTlsStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/edgeServicesWafStage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/edgeServicesWafStage:EdgeServicesWafStage": "EdgeServicesWafStage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/fileFilesystem",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/fileFilesystem:FileFilesystem": "FileFilesystem"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/flexibleIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/flexibleIp:FlexibleIp": "FlexibleIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/flexibleIpMacAddress",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/flexibleIpMacAddress:FlexibleIpMacAddress": "FlexibleIpMacAddress"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/function",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/function:Function": "Function"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionCron",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionCron:FunctionCron": "FunctionCron"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionDomain:FunctionDomain": "FunctionDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionNamespace:FunctionNamespace": "FunctionNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionToken",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionToken:FunctionToken": "FunctionToken"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/functionTrigger",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/functionTrigger:FunctionTrigger": "FunctionTrigger"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamApiKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamApiKey:IamApiKey": "IamApiKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamApplication",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamApplication:IamApplication": "IamApplication"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamGroup:IamGroup": "IamGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamGroupMembership",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamGroupMembership:IamGroupMembership": "IamGroupMembership"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamPolicy",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamPolicy:IamPolicy": "IamPolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamSshKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamSshKey:IamSshKey": "IamSshKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iamUser",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iamUser:IamUser": "IamUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/inferenceDeployment",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/inferenceDeployment:InferenceDeployment": "InferenceDeployment"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceImage",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceImage:InstanceImage": "InstanceImage"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceIp:InstanceIp": "InstanceIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceIpReverseDns:InstanceIpReverseDns": "InstanceIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instancePlacementGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instancePlacementGroup:InstancePlacementGroup": "InstancePlacementGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instancePrivateNic",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instancePrivateNic:InstancePrivateNic": "InstancePrivateNic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSecurityGroup",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSecurityGroup:InstanceSecurityGroup": "InstanceSecurityGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSecurityGroupRules",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSecurityGroupRules:InstanceSecurityGroupRules": "InstanceSecurityGroupRules"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceServer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceServer:InstanceServer": "InstanceServer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceSnapshot:InstanceSnapshot": "InstanceSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceUserData",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceUserData:InstanceUserData": "InstanceUserData"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/instanceVolume",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/instanceVolume:InstanceVolume": "InstanceVolume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotDevice",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotDevice:IotDevice": "IotDevice"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotHub",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotHub:IotHub": "IotHub"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotNetwork:IotNetwork": "IotNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/iotRoute",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/iotRoute:IotRoute": "IotRoute"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/ipamIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/ipamIp:IpamIp": "IpamIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/ipamIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/ipamIpReverseDns:IpamIpReverseDns": "IpamIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/jobDefinition",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/jobDefinition:JobDefinition": "JobDefinition"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/keyManagerKey",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/keyManagerKey:KeyManagerKey": "KeyManagerKey"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/kubernetesCluster",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/kubernetesCluster:KubernetesCluster": "KubernetesCluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/kubernetesNodePool",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/kubernetesNodePool:KubernetesNodePool": "KubernetesNodePool"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancer",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancer:Loadbalancer": "Loadbalancer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerAcl:LoadbalancerAcl": "LoadbalancerAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerBackend",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerBackend:LoadbalancerBackend": "LoadbalancerBackend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerCertificate",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerCertificate:LoadbalancerCertificate": "LoadbalancerCertificate"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerFrontend",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerFrontend:LoadbalancerFrontend": "LoadbalancerFrontend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerIp:LoadbalancerIp": "LoadbalancerIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/loadbalancerRoute",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/loadbalancerRoute:LoadbalancerRoute": "LoadbalancerRoute"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqNatsAccount",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqNatsAccount:MnqNatsAccount": "MnqNatsAccount"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqNatsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqNatsCredentials:MnqNatsCredentials": "MnqNatsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSns:MnqSns": "MnqSns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsCredentials:MnqSnsCredentials": "MnqSnsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsTopic",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsTopic:MnqSnsTopic": "MnqSnsTopic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSnsTopicSubscription",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSnsTopicSubscription:MnqSnsTopicSubscription": "MnqSnsTopicSubscription"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqs",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqs:MnqSqs": "MnqSqs"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqsCredentials",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqsCredentials:MnqSqsCredentials": "MnqSqsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mnqSqsQueue",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mnqSqsQueue:MnqSqsQueue": "MnqSqsQueue"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mongoDbInstance",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mongoDbInstance:MongoDbInstance": "MongoDbInstance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/mongoDbSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/mongoDbSnapshot:MongoDbSnapshot": "MongoDbSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucket",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucket:ObjectBucket": "ObjectBucket"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketAcl",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketAcl:ObjectBucketAcl": "ObjectBucketAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketLockConfiguration",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketLockConfiguration:ObjectBucketLockConfiguration": "ObjectBucketLockConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketPolicy",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketPolicy:ObjectBucketPolicy": "ObjectBucketPolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectBucketWebsiteConfiguration",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectBucketWebsiteConfiguration:ObjectBucketWebsiteConfiguration": "ObjectBucketWebsiteConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/objectItem",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/objectItem:ObjectItem": "ObjectItem"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/rdbSnapshot",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/rdbSnapshot:RdbSnapshot": "RdbSnapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/redisCluster",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/redisCluster:RedisCluster": "RedisCluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/registryNamespace",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/registryNamespace:RegistryNamespace": "RegistryNamespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/sdbDatabase",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/sdbDatabase:SdbDatabase": "SdbDatabase"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/secret",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/secretVersion",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/secretVersion:SecretVersion": "SecretVersion"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/temDomain",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/temDomain:TemDomain": "TemDomain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/temDomainValidation",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/temDomainValidation:TemDomainValidation": "TemDomainValidation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/temWebhook",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/temWebhook:TemWebhook": "TemWebhook"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpc",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpc:Vpc": "Vpc"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcGatewayNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcGatewayNetwork:VpcGatewayNetwork": "VpcGatewayNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPrivateNetwork",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPrivateNetwork:VpcPrivateNetwork": "VpcPrivateNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGateway",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGateway:VpcPublicGateway": "VpcPublicGateway"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayDhcp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayDhcp:VpcPublicGatewayDhcp": "VpcPublicGatewayDhcp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayDhcpReservation",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayDhcpReservation:VpcPublicGatewayDhcpReservation": "VpcPublicGatewayDhcpReservation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayIp",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayIp:VpcPublicGatewayIp": "VpcPublicGatewayIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayIpReverseDns",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayIpReverseDns:VpcPublicGatewayIpReverseDns": "VpcPublicGatewayIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcPublicGatewayPatRule",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcPublicGatewayPatRule:VpcPublicGatewayPatRule": "VpcPublicGatewayPatRule"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/vpcRoute",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/vpcRoute:VpcRoute": "VpcRoute"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "index/webhosting",
  "fqn": "pulumiverse_scaleway",
  "classes": {
   "scaleway:index/webhosting:Webhosting": "Webhosting"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "inference/deployment",
  "fqn": "pulumiverse_scaleway.inference",
  "classes": {
   "scaleway:inference/deployment:Deployment": "Deployment"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "inference/model",
  "fqn": "pulumiverse_scaleway.inference",
  "classes": {
   "scaleway:inference/model:Model": "Model"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/image",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/image:Image": "Image"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/ip",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/ip:Ip": "Ip"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/ipReverseDns",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/ipReverseDns:IpReverseDns": "IpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/placementGroup",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/placementGroup:PlacementGroup": "PlacementGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/privateNic",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/privateNic:PrivateNic": "PrivateNic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/securityGroup",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/securityGroup:SecurityGroup": "SecurityGroup"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/securityGroupRules",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/securityGroupRules:SecurityGroupRules": "SecurityGroupRules"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/server",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/server:Server": "Server"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/snapshot",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/userData",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/userData:UserData": "UserData"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "instance/volume",
  "fqn": "pulumiverse_scaleway.instance",
  "classes": {
   "scaleway:instance/volume:Volume": "Volume"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iot/device",
  "fqn": "pulumiverse_scaleway.iot",
  "classes": {
   "scaleway:iot/device:Device": "Device"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iot/hub",
  "fqn": "pulumiverse_scaleway.iot",
  "classes": {
   "scaleway:iot/hub:Hub": "Hub"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iot/network",
  "fqn": "pulumiverse_scaleway.iot",
  "classes": {
   "scaleway:iot/network:Network": "Network"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "iot/route",
  "fqn": "pulumiverse_scaleway.iot",
  "classes": {
   "scaleway:iot/route:Route": "Route"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "ipam/ip",
  "fqn": "pulumiverse_scaleway.ipam",
  "classes": {
   "scaleway:ipam/ip:Ip": "Ip"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "ipam/ipReverseDns",
  "fqn": "pulumiverse_scaleway.ipam",
  "classes": {
   "scaleway:ipam/ipReverseDns:IpReverseDns": "IpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "job/definition",
  "fqn": "pulumiverse_scaleway.job",
  "classes": {
   "scaleway:job/definition:Definition": "Definition"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "kubernetes/acl",
  "fqn": "pulumiverse_scaleway.kubernetes",
  "classes": {
   "scaleway:kubernetes/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "kubernetes/cluster",
  "fqn": "pulumiverse_scaleway.kubernetes",
  "classes": {
   "scaleway:kubernetes/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "kubernetes/pool",
  "fqn": "pulumiverse_scaleway.kubernetes",
  "classes": {
   "scaleway:kubernetes/pool:Pool": "Pool"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/acl",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/backend",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/backend:Backend": "Backend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/certificate",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/certificate:Certificate": "Certificate"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/frontend",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/frontend:Frontend": "Frontend"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/ip",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/ip:Ip": "Ip"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/loadBalancer",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/loadBalancer:LoadBalancer": "LoadBalancer"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "loadbalancers/route",
  "fqn": "pulumiverse_scaleway.loadbalancers",
  "classes": {
   "scaleway:loadbalancers/route:Route": "Route"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/natsAccount",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/natsAccount:NatsAccount": "NatsAccount"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/natsCredentials",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/natsCredentials:NatsCredentials": "NatsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/sns",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/sns:Sns": "Sns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/snsCredentials",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/snsCredentials:SnsCredentials": "SnsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/snsTopic",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/snsTopic:SnsTopic": "SnsTopic"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/snsTopicSubscription",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/snsTopicSubscription:SnsTopicSubscription": "SnsTopicSubscription"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/sqs",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/sqs:Sqs": "Sqs"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/sqsCredentials",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/sqsCredentials:SqsCredentials": "SqsCredentials"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mnq/sqsQueue",
  "fqn": "pulumiverse_scaleway.mnq",
  "classes": {
   "scaleway:mnq/sqsQueue:SqsQueue": "SqsQueue"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mongodb/instance",
  "fqn": "pulumiverse_scaleway.mongodb",
  "classes": {
   "scaleway:mongodb/instance:Instance": "Instance"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mongodb/snapshot",
  "fqn": "pulumiverse_scaleway.mongodb",
  "classes": {
   "scaleway:mongodb/snapshot:Snapshot": "Snapshot"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "mongodb/user",
  "fqn": "pulumiverse_scaleway.mongodb",
  "classes": {
   "scaleway:mongodb/user:User": "User"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/acl",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/acl:Acl": "Acl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/gatewayNetwork",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/gatewayNetwork:GatewayNetwork": "GatewayNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/privateNetwork",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/privateNetwork:PrivateNetwork": "PrivateNetwork"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGateway",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGateway:PublicGateway": "PublicGateway"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayDhcp",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayDhcp:PublicGatewayDhcp": "PublicGatewayDhcp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayDhcpReservation",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayDhcpReservation:PublicGatewayDhcpReservation": "PublicGatewayDhcpReservation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayIp",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayIp:PublicGatewayIp": "PublicGatewayIp"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayIpReverseDns",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayIpReverseDns:PublicGatewayIpReverseDns": "PublicGatewayIpReverseDns"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/publicGatewayPatRule",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/publicGatewayPatRule:PublicGatewayPatRule": "PublicGatewayPatRule"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/route",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/route:Route": "Route"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "network/vpc",
  "fqn": "pulumiverse_scaleway.network",
  "classes": {
   "scaleway:network/vpc:Vpc": "Vpc"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucket",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucket:Bucket": "Bucket"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucketAcl",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucketAcl:BucketAcl": "BucketAcl"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucketLockConfiguration",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucketLockConfiguration:BucketLockConfiguration": "BucketLockConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucketPolicy",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucketPolicy:BucketPolicy": "BucketPolicy"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/bucketWebsiteConfiguration",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/bucketWebsiteConfiguration:BucketWebsiteConfiguration": "BucketWebsiteConfiguration"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "object/item",
  "fqn": "pulumiverse_scaleway.object",
  "classes": {
   "scaleway:object/item:Item": "Item"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/alertManager",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/alertManager:AlertManager": "AlertManager"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/cockpit",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/cockpit:Cockpit": "Cockpit"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/grafanaUser",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/grafanaUser:GrafanaUser": "GrafanaUser"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/source",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/source:Source": "Source"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "observability/token",
  "fqn": "pulumiverse_scaleway.observability",
  "classes": {
   "scaleway:observability/token:Token": "Token"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "redis/cluster",
  "fqn": "pulumiverse_scaleway.redis",
  "classes": {
   "scaleway:redis/cluster:Cluster": "Cluster"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "registry/namespace",
  "fqn": "pulumiverse_scaleway.registry",
  "classes": {
   "scaleway:registry/namespace:Namespace": "Namespace"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "secrets/secret",
  "fqn": "pulumiverse_scaleway.secrets",
  "classes": {
   "scaleway:secrets/secret:Secret": "Secret"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "secrets/version",
  "fqn": "pulumiverse_scaleway.secrets",
  "classes": {
   "scaleway:secrets/version:Version": "Version"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "tem/blockedList",
  "fqn": "pulumiverse_scaleway.tem",
  "classes": {
   "scaleway:tem/blockedList:BlockedList": "BlockedList"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "tem/domain",
  "fqn": "pulumiverse_scaleway.tem",
  "classes": {
   "scaleway:tem/domain:Domain": "Domain"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "tem/domainValidation",
  "fqn": "pulumiverse_scaleway.tem",
  "classes": {
   "scaleway:tem/domainValidation:DomainValidation": "DomainValidation"
  }
 },
 {
  "pkg": "scaleway",
  "mod": "tem/webhook",
  "fqn": "pulumiverse_scaleway.tem",
  "classes": {
   "scaleway:tem/webhook:Webhook": "Webhook"
  }
 }
]
""",
    resource_packages="""
[
 {
  "pkg": "scaleway",
  "token": "pulumi:providers:scaleway",
  "fqn": "pulumiverse_scaleway",
  "class": "Provider"
 }
]
"""
)
